@@ -1,6 +1,7 @@
 #![cfg_attr(RUSTC_WITH_SPECIALIZATION, feature(min_specialization))]
 
 pub mod accounts_data_meter;
+pub mod compute_budget;
 pub mod instruction_recorder;
 pub mod invoke_context;
 pub mod log_collector;
@@ -8,4 +9,5 @@ pub mod native_loader;
 pub mod neon_evm_program;
 pub mod pre_account;
 pub mod stable_log;
+pub mod sysvar_cache;
 pub mod timings;
